==> org-lsst-ccs-ui-2.2.7-sources.jar: org/lsst/ccs/gconsole/plugins/console/LsstConsolePlugin.java <==
package org.lsst.ccs.gconsole.plugins.console;

import java.awt.event.ActionEvent;
import java.io.IOException;
import javax.swing.AbstractAction;
import javax.swing.Action;
import org.freehep.jas.extensions.jconsole.JConsoleService;
import org.freehep.jas.extensions.jconsole.JLineConsole;
import org.freehep.jas.extensions.jconsole.JLineConsoleProvider;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.Plugin;
import org.lsst.ccs.shell.JLineShell;
import org.lsst.ccs.subsystem.shell.ConsoleCommandShell;

/**
 * Plugin that creates and manages command consoles.
 */
@Plugin(name="LSST Console Plugin",
        id="console",
        description="LSST command console plugin.")
public class LsstConsolePlugin extends ConsolePlugin {
    
// -- Fields : -----------------------------------------------------------------

    private final String defaultConsoleName = "LSST CCS Command Console";


// -- Life cycle : -------------------------------------------------------------
    
    @Override
    synchronized public void initialize() {
        Action newConsoleAction = new AbstractAction("Command Line") {
            @Override
            public void actionPerformed(ActionEvent e) {
                createCommandConsole(defaultConsoleName);
            }
        };
        getServices().addMenu(newConsoleAction, "400: CCS Tools :-1:1");
    }

    @Override
    synchronized public void start() {
        JConsoleService cs = (JConsoleService) getConsole().getConsoleLookup().lookup(JConsoleService.class);
        if (cs == null) throw new IllegalStateException("JConsole service is not available");
        cs.addConsoleProvider(JLineConsole.class, new JLineConsoleProvider());
    }
    
    
// -- Handling consoles : ------------------------------------------------------

    synchronized private JLineConsole createCommandConsole(String name) {
        try {
            JConsoleService cs = (JConsoleService) getConsole().getConsoleLookup().lookup(JConsoleService.class);
            if (cs != null) {
                JLineConsole console = (JLineConsole) cs.createConsole(JLineConsole.class, name, null, null);
                JLineShell shell = ConsoleCommandShell.createJLineShell(getConsole().getMessagingAccess(), console.getConsoleReader());
                Thread t = new Thread("ConsoleInput-" + name) {
                    @Override
                    public void run() {
                        try {
                            shell.run();
                        } catch (IOException x) {
                            getConsole().error("Error in command shell", x);
                        } finally {
                        }
                    }
                };
                t.start();
                return console;
            }
        } catch (Exception x) {
            getConsole().error("Failed to start Console: " + name, x);
        }
        return null;
    }
    
}

==> org-lsst-ccs-ui-2.3.7-sources.jar: org/lsst/ccs/gconsole/plugins/console/LsstConsolePlugin.java <==
package org.lsst.ccs.gconsole.plugins.console;

import java.awt.event.ActionEvent;
import java.io.IOException;
import javax.swing.AbstractAction;
import javax.swing.Action;
import org.freehep.jas.extensions.jconsole.JConsoleService;
import org.freehep.jas.extensions.jconsole.JLineConsole;
import org.freehep.jas.extensions.jconsole.JLineConsoleProvider;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.annotations.Plugin;
import org.lsst.ccs.shell.JLineShell;
import org.lsst.ccs.subsystem.shell.ConsoleCommandShell;

/**
 * Plugin that creates and manages command consoles.
 */
@Plugin(name="LSST Console Plugin",
        id="console",
        description="LSST command console plugin.")
public class LsstConsolePlugin extends ConsolePlugin {
    
// -- Fields : -----------------------------------------------------------------

    private final String defaultConsoleName = "LSST CCS Command Console";


// -- Life cycle : -------------------------------------------------------------
    
    @Override
    synchronized public void initialize() {
        Action newConsoleAction = new AbstractAction("Command Line") {
            @Override
            public void actionPerformed(ActionEvent e) {
                createCommandConsole(defaultConsoleName);
            }
        };
        getServices().addMenu(newConsoleAction, "400: CCS Tools :-1:1");
    }

    @Override
    synchronized public void start() {
        JConsoleService cs = (JConsoleService) getConsole().getConsoleLookup().lookup(JConsoleService.class);
        if (cs == null) throw new IllegalStateException("JConsole service is not available");
        cs.addConsoleProvider(JLineConsole.class, new JLineConsoleProvider());
    }
    
    
// -- Handling consoles : ------------------------------------------------------

    synchronized private JLineConsole createCommandConsole(String name) {
        try {
            JConsoleService cs = (JConsoleService) getConsole().getConsoleLookup().lookup(JConsoleService.class);
            if (cs != null) {
                JLineConsole console = (JLineConsole) cs.createConsole(JLineConsole.class, name, null, null);
                JLineShell shell = ConsoleCommandShell.createJLineShell(getConsole().getMessagingAccess(), console.getConsoleReader());
                Thread t = new Thread("ConsoleInput-" + name) {
                    @Override
                    public void run() {
                        try {
                            shell.run();
                        } catch (IOException x) {
                            getConsole().error("Error in command shell", x);
                        } finally {
                        }
                    }
                };
                t.start();
                return console;
            }
        } catch (Exception x) {
            getConsole().error("Failed to start Console: " + name, x);
        }
        return null;
    }
    
}
